@@ -118,7 +118,7 @@ class DiscreteEnv(gym.Env):
       #reward = self.Ynew_cumul 
     
     done = bool(self.horizon <= 0)
-    if done=True:
+    if done:
       reward = self.Ynew_cumul
     else:
       done = False 
